
/* Sphere.h provides the Sphere class.
 * ... other documentation omitted ...
 ***************************************************************/

#include <string>            // class string
#include <sstream>           //istringstream, ostringstream

#include <cmath>
using namespace std;

class Sphere
{
 public:
   Sphere();
   Sphere(string sphereAttributes);  // convert string to Name
   // ... other constructors omitted ...

   string asString() const;          // convert Sphere to string
   
   void readRadiusAndDensity(istream& in);
   void setRadiusAndDensity(double radius, double density);
   // ... other methods omitted ...
   
   void print(ostream& out) const;

 private:
   double myRadius, myDensity, myWeight;
};

inline Sphere::Sphere()
{
  myRadius = myDensity = myWeight = 0.0;
}
      
inline Sphere::Sphere(string sphereAttributes)
{
   istringstream ssin(sphereAttributes);
   ssin >> myRadius >> myDensity >> myWeight;
}

inline string Sphere::asString() const
{
   ostringstream ssout;
   ssout << myRadius << ' ' << myDensity << ' ' << myWeight;
   return ssout.str();
}

inline void Sphere::print(ostream& out) const
{
   out << "Sphere, radius: " << myRadius 
       << ", density: " << myDensity 
       << ", weight: " << myWeight;
}

inline void Sphere::readRadiusAndDensity(istream& in)
{
  double radius, density;
  in >> radius >> density;
  setRadiusAndDensity(radius, density);
}

const double PI = 3.14159;

inline void Sphere::setRadiusAndDensity(double newRadius, double newDensity)
{
  if (newRadius > 0.0 && newDensity > 0.0) {
    myRadius = newRadius;
    myDensity = newDensity;
    myWeight = newDensity * 4.0 * PI * pow(newRadius, 3.0) / 3.0;
  }
  else {
    cerr << "setRadiusAndDensity(r,d): r,d must be non-negative" << endl;
  }
}
